@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.44 2003/11/14 04:43:18 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.46 2003/11/21 07:38:06 muppetman Exp $
 #
 
 package Gtk2;
@@ -31,7 +31,7 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '1.011';
+our $VERSION = '1.012';
 
 our @ISA = qw(DynaLoader);
 
@@ -128,9 +128,11 @@ sub create_item {
 	}
 
 	# we have this funky perl wrapper for the XS function entirely for
-	# this line right here --- strip underscores from the possibly unicode
-	# path, for use with gtk_item_factory_get_widget.
-	($cleanpath = $path) =~ s/_//g;
+	# those three lines right here --- strip underscores from the possibly
+	# unicode path, for use with gtk_item_factory_get_widget.
+	$cleanpath = $path;
+	$cleanpath =~ s/_(?!_+)//g;
+	$cleanpath =~ s/_+/_/;
 
 	# the rest of the work happens in XS
 	$factory->_create_item ($path, $accelerator || '',
